@@ -1,17 +1,14 @@
 """This module defines the HGNC ETL methods."""
-import logging
-import json
-from pathlib import Path
-import shutil
-import re
-from typing import Dict, List
-
+from .base import Base
 from gene import APP_ROOT, PREFIX_LOOKUP
-from gene.database import AbstractDatabase
 from gene.schemas import SourceName, SymbolStatus, NamespacePrefix, \
     SourceMeta, Annotation, Chromosome
-from gene.etl.base import Base
-from gene.etl.vrs_locations import ChromosomeLocation
+from gene.database import Database
+import logging
+import json
+import shutil
+import re
+from gene.vrs_locations import ChromosomeLocation
 
 logger = logging.getLogger('gene')
 logger.setLevel(logging.DEBUG)
@@ -21,19 +18,19 @@ class HGNC(Base):
     """ETL the HGNC source into the normalized database."""
 
     def __init__(self,
-                 database: AbstractDatabase,
-                 host: str = 'ftp.ebi.ac.uk',
-                 data_dir: str = 'pub/databases/genenames/hgnc/json/',
-                 src_data_dir: Path = APP_ROOT / 'data' / 'hgnc',
-                 fn: str = 'hgnc_complete_set.json'
-                 ) -> None:
+                 database: Database,
+                 host='ftp.ebi.ac.uk',
+                 data_dir='pub/databases/genenames/hgnc/json/',
+                 src_data_dir=APP_ROOT / 'data' / 'hgnc',
+                 fn='hgnc_complete_set.json'
+                 ):
         """Initialize HGNC ETL class.
 
-        :param database: DynamoDB database
-        :param host: FTP host name
-        :param data_dir: FTP data directory to use
-        :param src_data_dir: Data directory for HGNC
-        :param fn: Data file to download
+        :param Database database: DynamoDB database
+        :param str host: FTP host name
+        :param str data_dir: FTP data directory to use
+        :param Path src_data_dir: Data directory for HGNC
+        :param str fn: Data file to download
         """
         super().__init__(database, host, data_dir, src_data_dir)
         self._chromosome_location = ChromosomeLocation()
@@ -41,7 +38,7 @@ class HGNC(Base):
         self._fn = fn
         self._version = None
 
-    def _download_data(self, *args, **kwargs) -> None:
+    def _download_data(self, *args, **kwargs):
         """Download HGNC JSON data file."""
         logger.info('Downloading HGNC data file...')
         self._create_data_directory()
@@ -53,14 +50,14 @@ class HGNC(Base):
                     f"{self.src_data_dir}/hgnc_{self._version}.json")
         logger.info('Successfully downloaded HGNC data file.')
 
-    def _extract_data(self, *args, **kwargs) -> None:
+    def _extract_data(self, *args, **kwargs):
         """Extract data from the HGNC source."""
         if 'data_path' in kwargs:
             self._data_src = kwargs['data_path']
         else:
             self._data_src = sorted(list(self.src_data_dir.iterdir()))[-1]
 
-    def _transform_data(self, *args, **kwargs) -> None:
+    def _transform_data(self, *args, **kwargs):
         """Transform the HGNC source."""
         logger.info('Transforming HGNC...')
         with open(self._data_src, 'r') as f:
@@ -68,40 +65,42 @@ class HGNC(Base):
 
         records = data['response']['docs']
 
-        for r in records:
-            gene = dict()
-            gene["concept_id"] = r["hgnc_id"].lower()
-            gene["label_and_type"] = f"{gene['concept_id']}##identity"
-            gene["item_type"] = "identity"
-            gene["symbol"] = r["symbol"]
-            gene["label"] = r["name"]
-            gene["src_name"] = SourceName.HGNC.value
-            if r["status"]:
-                if r["status"] == "Approved":
-                    gene["symbol_status"] = \
-                        SymbolStatus.APPROVED.value
-                elif r["status"] == "Entry Withdrawn":
-                    gene["symbol_status"] =\
-                        SymbolStatus.WITHDRAWN.value
-            gene["src_name"] = SourceName.HGNC.value
+        with self._database.genes.batch_writer() as batch:
+            for r in records:
+                gene = dict()
+                gene['concept_id'] = r['hgnc_id'].lower()
+                gene['label_and_type'] = \
+                    f"{gene['concept_id']}##identity"
+                gene['item_type'] = 'identity'
+                gene['symbol'] = r['symbol']
+                gene['label'] = r['name']
+                gene['src_name'] = SourceName.HGNC.value
+                if r['status']:
+                    if r['status'] == 'Approved':
+                        gene['symbol_status'] = \
+                            SymbolStatus.APPROVED.value
+                    elif r['status'] == 'Entry Withdrawn':
+                        gene['symbol_status'] =\
+                            SymbolStatus.WITHDRAWN.value
+                gene['src_name'] = SourceName.HGNC.value
 
-            # store alias, xref, associated_with, prev_symbols, location
-            self._get_aliases(r, gene)
-            self._get_xrefs_associated_with(r, gene)
-            if "prev_symbol" in r:
-                self._get_previous_symbols(r, gene)
-            if "location" in r:
-                self._get_location(r, gene)
-            if "locus_type" in r:
-                gene["gene_type"] = r["locus_type"]
-                self._load_gene(gene)
-        logger.info("Successfully transformed HGNC.")
+                # store alias, xref, associated_with, prev_symbols, location
+                self._get_aliases(r, gene)
+                self._get_xrefs_associated_with(r, gene)
+                if 'prev_symbol' in r:
+                    self._get_previous_symbols(r, gene)
+                if 'location' in r:
+                    self._get_location(r, gene)
+                if "locus_type" in r:
+                    gene["gene_type"] = r["locus_type"]
+                self._load_gene(gene, batch)
+        logger.info('Successfully transformed HGNC.')
 
-    def _get_aliases(self, r: Dict, gene: Dict) -> None:
+    def _get_aliases(self, r, gene):
         """Store aliases in a gene record.
 
-        :param r: A gene record in the HGNC data file
-        :param gene: A transformed gene record
+        :param dict r: A gene record in the HGNC data file
+        :param dict gene: A transformed gene record
         """
         alias_symbol = list()
         enzyme_id = list()
@@ -114,21 +113,21 @@ class HGNC(Base):
         if alias_symbol or enzyme_id:
             gene['aliases'] = list(set(alias_symbol + enzyme_id))
 
-    def _get_previous_symbols(self, r: Dict, gene: Dict) -> None:
+    def _get_previous_symbols(self, r, gene):
         """Store previous symbols in a gene record.
 
-        :param r: A gene record in the HGNC data file
-        :param gene: A transformed gene record
+        :param dict r: A gene record in the HGNC data file
+        :param dict gene: A transformed gene record
         """
         prev_symbols = r['prev_symbol']
         if prev_symbols:
             gene['previous_symbols'] = list(set(prev_symbols))
 
-    def _get_xrefs_associated_with(self, r: Dict, gene: Dict) -> None:
+    def _get_xrefs_associated_with(self, r, gene):
         """Store xrefs and/or associated_with refs in a gene record.
 
-        :param r: A gene record in the HGNC data file
-        :param gene: A transformed gene record
+        :param dict r: A gene record in the HGNC data file
+        :param dict gene: A transformed gene record
         """
         xrefs = list()
         associated_with = list()
@@ -166,15 +165,13 @@ class HGNC(Base):
         if associated_with:
             gene['associated_with'] = associated_with
 
-    def _get_xref_associated_with(
-        self, key: str, src: str, r: Dict, src_type: Dict
-    ) -> None:
+    def _get_xref_associated_with(self, key, src, r, src_type):
         """Add an xref or associated_with ref to a gene record.
 
-        :param key: The source's name
-        :param src: HGNC's source field
-        :param r: A gene record in the HGNC data file
-        :param src_type: Either xrefs or associated_with list
+        :param str key: The source's name
+        :param str src: HGNC's source field
+        :param dict r: A gene record in the HGNC data file
+        :param list src_type: Either xrefs or associated_with list
         """
         if type(r[src]) == list:
             for xref in r[src]:
@@ -187,12 +184,12 @@ class HGNC(Base):
                 f"{NamespacePrefix[key.upper()].value}"
                 f":{r[src]}")
 
-    def _get_location(self, r: Dict, gene: Dict) -> None:
+    def _get_location(self, r, gene):
         """Store GA4GH VRS ChromosomeLocation in a gene record.
         https://vr-spec.readthedocs.io/en/1.1/terms_and_model.html#chromosomelocation
 
-        :param r: A gene record in the HGNC data file
-        :param gene: A transformed gene record
+        :param dict r: A gene record in the HGNC data file
+        :param dict gene: A transformed gene record
         """
         # Get list of a gene's map locations
         if 'and' in r['location']:
@@ -223,12 +220,11 @@ class HGNC(Base):
         if not gene['location_annotations']:
             del gene['location_annotations']
 
-    def _set_annotation(self, loc: str, gene: Dict) -> None:
+    def _set_annotation(self, loc, gene):
         """Set the annotations attribute if one is provided.
-        Return `True` if a location is provided, `False` otherwise.
+           Return `True` if a location is provided, `False` otherwise.
 
-        :param loc: A gene location
-        :param gene: in-progress gene record
+        :param str loc: A gene location
         :return: A bool whether or not a gene map location is provided
         """
         annotations = {v.value for v in
@@ -243,12 +239,12 @@ class HGNC(Base):
                     return None
         return loc
 
-    def _set_location(self, loc: str, location: Dict, gene: Dict) -> None:
+    def _set_location(self, loc, location, gene):
         """Set a gene's location.
 
-        :param loc: A gene location
-        :param location: GA4GH location
-        :param gene: A transformed gene record
+        :param str loc: A gene location
+        :param dict location: GA4GH location
+        :param dict gene: A transformed gene record
         """
         arm_match = re.search('[pq]', loc)
 
@@ -259,7 +255,8 @@ class HGNC(Base):
 
             if '-' in loc:
                 # Location gives both start and end
-                self._chromosome_location.set_interval_range(loc, arm_ix, location)
+                self._chromosome_location.set_interval_range(loc,
+                                                             arm_ix, location)
             else:
                 # Location only gives start
                 start = loc[arm_ix:]
@@ -269,7 +266,7 @@ class HGNC(Base):
             # Only gives chromosome
             gene['location_annotations'].append(loc)
 
-    def perform_etl(self, *args, **kwargs) -> List[str]:
+    def perform_etl(self, *args, **kwargs):
         """Extract, Transform, and Load data into DynamoDB database.
 
         :return: Concept IDs of concepts successfully loaded
@@ -278,10 +275,10 @@ class HGNC(Base):
         self._extract_data()
         self._add_meta()
         self._transform_data()
-        self._database.complete_write_transaction()
+        self._database.flush_batch()
         return self._processed_ids
 
-    def _add_meta(self) -> None:
+    def _add_meta(self, *args, **kwargs):
         """Add HGNC metadata to the gene_metadata table."""
         metadata = SourceMeta(
             data_license='custom',
@@ -296,4 +293,5 @@ class HGNC(Base):
             },
             genome_assemblies=[]
         )
-        self._database.add_source_metadata(SourceName.HGNC, metadata)
+
+        self._load_meta(self._database, metadata, SourceName.HGNC.value)
