@@ -3,16 +3,13 @@ from fastapi import FastAPI, HTTPException, Query
 from fastapi.openapi.utils import get_openapi
 from typing import Optional
 from gene import __version__
-from gene.database import create_db
 from gene.query import QueryHandler, InvalidParameterException
 from gene.schemas import SearchService, NormalizeService, \
     UnmergedNormalizationService
 import html
 
 
-db = create_db()
-query_handler = QueryHandler(db)
-
+query_handler = QueryHandler()
 app = FastAPI(
     docs_url="/gene",
     openapi_url="/gene/openapi.json",
